==> RelevanceAI-dev-2.0.0.2022.3.27.9.25.1.443857.tar.gz: RelevanceAI-dev-2.0.0.2022.3.27.9.25.1.443857/relevanceai/_api/endpoints/services/services.py <==
"""Services class
"""
from typing import Optional

from relevanceai.utils.base import _Base

from relevanceai._api.endpoints.services.encoders import EncodersClient
from relevanceai._api.endpoints.services.cluster import ClusterClient
from relevanceai._api.endpoints.services.search import SearchClient
from relevanceai._api.endpoints.services.aggregate import AggregateClient
from relevanceai._api.endpoints.services.recommend import RecommendClient
from relevanceai._api.endpoints.services.tagger import TaggerClient
from relevanceai._api.endpoints.services.prediction import PredictionClient
from relevanceai._api.endpoints.services.wordclouds import WordcloudsClient


class ServicesClient(_Base):
    def __init__(self, project: str, api_key: str, firebase_uid: str):
        self.project = project
        self.api_key = api_key
        self.firebase_uid = firebase_uid

        self.encoders = EncodersClient(
            project=project, api_key=api_key, firebase_uid=firebase_uid
        )
        self.cluster = ClusterClient(
            project=project, api_key=api_key, firebase_uid=firebase_uid
        )
        self.search = SearchClient(
            project=project, api_key=api_key, firebase_uid=firebase_uid
        )
        self.aggregate = AggregateClient(
            project=project, api_key=api_key, firebase_uid=firebase_uid
        )
        self.recommend = RecommendClient(
            project=project, api_key=api_key, firebase_uid=firebase_uid
        )
        self.tagger = TaggerClient(
            project=project, api_key=api_key, firebase_uid=firebase_uid
        )
        self.prediction = PredictionClient(
            project=project, api_key=api_key, firebase_uid=firebase_uid
        )
        self.wordclouds = WordcloudsClient(
            project=project, api_key=api_key, firebase_uid=firebase_uid
        )
        super().__init__(project=project, api_key=api_key, firebase_uid=firebase_uid)

    def document_diff(
        self,
        doc: dict,
        documents_to_compare: list,
        difference_fields: Optional[list] = None,
    ):
        """
        Find differences between documents

        Parameters
        ----------
        doc: dict
            Main document to compare other documents against.
        documents_to_compare: list
            Other documents to compare against the main document.
        difference_fields: list
            Fields to compare. Defaults to [], which compares all fields.

        """
        difference_fields = [] if difference_fields is None else difference_fields

        return self.make_http_request(
            endpoint=f"/services/document_diff",
            method="POST",
            parameters={
                "doc": doc,
                "documents_to_compare": documents_to_compare,
                "difference_fields": difference_fields,
            },
        )

==> RelevanceAI-dev-2.1.4.2022.4.26.3.55.16.533981.tar.gz: RelevanceAI-dev-2.1.4.2022.4.26.3.55.16.533981/relevanceai/_api/endpoints/services/services.py <==
"""Services class
"""
from typing import Optional

from relevanceai.utils.base import _Base

from relevanceai._api.endpoints.services.encoders import EncodersClient
from relevanceai._api.endpoints.services.cluster import ClusterClient
from relevanceai._api.endpoints.services.search import SearchClient
from relevanceai._api.endpoints.services.aggregate import AggregateClient
from relevanceai._api.endpoints.services.recommend import RecommendClient
from relevanceai._api.endpoints.services.tagger import TaggerClient
from relevanceai._api.endpoints.services.prediction import PredictionClient
from relevanceai._api.endpoints.services.wordclouds import WordcloudsClient
from relevanceai._api.endpoints.services.centroids import CentroidsClient


class ServicesClient(_Base):
    def __init__(self, credentials):
        self.encoders = EncodersClient(credentials)
        self.cluster = ClusterClient(credentials)
        self.search = SearchClient(credentials)
        self.aggregate = AggregateClient(credentials)
        self.recommend = RecommendClient(credentials)
        self.tagger = TaggerClient(credentials)
        self.prediction = PredictionClient(credentials)
        self.wordclouds = WordcloudsClient(credentials)
        self.centroids = CentroidsClient(credentials)
        super().__init__(credentials)

    def document_diff(
        self,
        doc: dict,
        documents_to_compare: list,
        difference_fields: Optional[list] = None,
    ):
        """
        Find differences between documents

        Parameters
        ----------
        doc: dict
            Main document to compare other documents against.
        documents_to_compare: list
            Other documents to compare against the main document.
        difference_fields: list
            Fields to compare. Defaults to [], which compares all fields.

        """
        difference_fields = [] if difference_fields is None else difference_fields

        return self.make_http_request(
            endpoint=f"/services/document_diff",
            method="POST",
            parameters={
                "doc": doc,
                "documents_to_compare": documents_to_compare,
                "difference_fields": difference_fields,
            },
        )
